Class: Manticore::Client::SearchRequest
- Inherits:
-
Object
- Object
- Manticore::Client::SearchRequest
- Defined in:
- lib/manticore/client/models/search_request.rb
Overview
Request object for search operation
Instance Attribute Summary collapse
-
#_source ⇒ Object
Returns the value of attribute _source.
-
#aggs ⇒ Object
Defines aggregation settings for grouping results.
-
#expressions ⇒ Object
Expressions to calculate additional values for the result.
-
#highlight ⇒ Object
Returns the value of attribute highlight.
-
#join ⇒ Object
Join clause to combine search data from multiple tables.
-
#knn ⇒ Object
Returns the value of attribute knn.
-
#limit ⇒ Object
Maximum number of results to return.
-
#max_matches ⇒ Object
Maximum number of matches allowed in the result.
-
#offset ⇒ Object
Starting point for pagination of the result.
-
#options ⇒ Object
Additional search options.
-
#profile ⇒ Object
Enable or disable profiling of the search request.
-
#query ⇒ Object
Returns the value of attribute query.
-
#sort ⇒ Object
Returns the value of attribute sort.
-
#table ⇒ Object
The table to perform the search on.
-
#track_scores ⇒ Object
Enable or disable result weight calculation used for sorting.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SearchRequest
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/manticore/client/models/search_request.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Manticore::Client::SearchRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Manticore::Client::SearchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'table') self.table = attributes[:'table'] else self.table = nil end if attributes.key?(:'query') self.query = attributes[:'query'] end if attributes.key?(:'join') if (value = attributes[:'join']).is_a?(Array) self.join = value end end if attributes.key?(:'highlight') self.highlight = attributes[:'highlight'] end if attributes.key?(:'limit') self.limit = attributes[:'limit'] end if attributes.key?(:'knn') self.knn = attributes[:'knn'] end if attributes.key?(:'aggs') if (value = attributes[:'aggs']).is_a?(Hash) self.aggs = value end end if attributes.key?(:'expressions') if (value = attributes[:'expressions']).is_a?(Hash) self.expressions = value end end if attributes.key?(:'max_matches') self.max_matches = attributes[:'max_matches'] end if attributes.key?(:'offset') self.offset = attributes[:'offset'] end if attributes.key?(:'options') self. = attributes[:'options'] end if attributes.key?(:'profile') self.profile = attributes[:'profile'] end if attributes.key?(:'sort') self.sort = attributes[:'sort'] end if attributes.key?(:'_source') self._source = attributes[:'_source'] end if attributes.key?(:'track_scores') self.track_scores = attributes[:'track_scores'] end end |
Instance Attribute Details
#_source ⇒ Object
Returns the value of attribute _source.
54 55 56 |
# File 'lib/manticore/client/models/search_request.rb', line 54 def _source @_source end |
#aggs ⇒ Object
Defines aggregation settings for grouping results
35 36 37 |
# File 'lib/manticore/client/models/search_request.rb', line 35 def aggs @aggs end |
#expressions ⇒ Object
Expressions to calculate additional values for the result
38 39 40 |
# File 'lib/manticore/client/models/search_request.rb', line 38 def expressions @expressions end |
#highlight ⇒ Object
Returns the value of attribute highlight.
27 28 29 |
# File 'lib/manticore/client/models/search_request.rb', line 27 def highlight @highlight end |
#join ⇒ Object
Join clause to combine search data from multiple tables
25 26 27 |
# File 'lib/manticore/client/models/search_request.rb', line 25 def join @join end |
#knn ⇒ Object
Returns the value of attribute knn.
32 33 34 |
# File 'lib/manticore/client/models/search_request.rb', line 32 def knn @knn end |
#limit ⇒ Object
Maximum number of results to return
30 31 32 |
# File 'lib/manticore/client/models/search_request.rb', line 30 def limit @limit end |
#max_matches ⇒ Object
Maximum number of matches allowed in the result
41 42 43 |
# File 'lib/manticore/client/models/search_request.rb', line 41 def max_matches @max_matches end |
#offset ⇒ Object
Starting point for pagination of the result
44 45 46 |
# File 'lib/manticore/client/models/search_request.rb', line 44 def offset @offset end |
#options ⇒ Object
Additional search options
47 48 49 |
# File 'lib/manticore/client/models/search_request.rb', line 47 def end |
#profile ⇒ Object
Enable or disable profiling of the search request
50 51 52 |
# File 'lib/manticore/client/models/search_request.rb', line 50 def profile @profile end |
#query ⇒ Object
Returns the value of attribute query.
22 23 24 |
# File 'lib/manticore/client/models/search_request.rb', line 22 def query @query end |
#sort ⇒ Object
Returns the value of attribute sort.
52 53 54 |
# File 'lib/manticore/client/models/search_request.rb', line 52 def sort @sort end |
#table ⇒ Object
The table to perform the search on
20 21 22 |
# File 'lib/manticore/client/models/search_request.rb', line 20 def table @table end |
#track_scores ⇒ Object
Enable or disable result weight calculation used for sorting
57 58 59 |
# File 'lib/manticore/client/models/search_request.rb', line 57 def track_scores @track_scores end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/manticore/client/models/search_request.rb', line 295 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Manticore::Client.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/manticore/client/models/search_request.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/manticore/client/models/search_request.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/manticore/client/models/search_request.rb', line 60 def self.attribute_map { :'table' => :'table', :'query' => :'query', :'join' => :'join', :'highlight' => :'highlight', :'limit' => :'limit', :'knn' => :'knn', :'aggs' => :'aggs', :'expressions' => :'expressions', :'max_matches' => :'max_matches', :'offset' => :'offset', :'options' => :'options', :'profile' => :'profile', :'sort' => :'sort', :'_source' => :'_source', :'track_scores' => :'track_scores' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/manticore/client/models/search_request.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 116 117 |
# File 'lib/manticore/client/models/search_request.rb', line 112 def self.openapi_nullable Set.new([ :'sort', :'_source', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/manticore/client/models/search_request.rb', line 91 def self.openapi_types { :'table' => :'String', :'query' => :'SearchQuery', :'join' => :'Array<Join>', :'highlight' => :'Highlight', :'limit' => :'Integer', :'knn' => :'KnnQuery', :'aggs' => :'Hash<String, Aggregation>', :'expressions' => :'Hash<String, String>', :'max_matches' => :'Integer', :'offset' => :'Integer', :'options' => :'Object', :'profile' => :'Boolean', :'sort' => :'Object', :'_source' => :'Object', :'track_scores' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/manticore/client/models/search_request.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && table == o.table && query == o.query && join == o.join && highlight == o.highlight && limit == o.limit && knn == o.knn && aggs == o.aggs && expressions == o.expressions && max_matches == o.max_matches && offset == o.offset && == o. && profile == o.profile && sort == o.sort && _source == o._source && track_scores == o.track_scores end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/manticore/client/models/search_request.rb', line 366 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/manticore/client/models/search_request.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/manticore/client/models/search_request.rb', line 264 def hash [table, query, join, highlight, limit, knn, aggs, expressions, max_matches, offset, , profile, sort, _source, track_scores].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
206 207 208 209 210 211 212 213 214 |
# File 'lib/manticore/client/models/search_request.rb', line 206 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @table.nil? invalid_properties.push('invalid value for "table", table cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
342 343 344 |
# File 'lib/manticore/client/models/search_request.rb', line 342 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/manticore/client/models/search_request.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/manticore/client/models/search_request.rb', line 336 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 |
# File 'lib/manticore/client/models/search_request.rb', line 218 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @table.nil? true end |