Class: Manticore::Client::UtilsApi
- Inherits:
-
Object
- Object
- Manticore::Client::UtilsApi
- Defined in:
- lib/manticore/client/api/utils_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ UtilsApi
constructor
A new instance of UtilsApi.
-
#sql(body, opts = {}) ⇒ SqlResponse
Perform SQL requests Run a query in SQL format.
-
#sql_with_http_info(body, opts = {}) ⇒ Array<(SqlResponse, Integer, Hash)>
Perform SQL requests Run a query in SQL format.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/manticore/client/api/utils_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#sql(body, opts = {}) ⇒ SqlResponse
Perform SQL requests
Run a query in SQL format. Expects a query string passed through body parameter and optional raw_response parameter that defines a format of response. raw_response can be set to False for Select queries only, e.g., SELECT * FROM mytable The query string must stay as it is, no URL encoding is needed. The response object depends on the query executed. In select mode the response has same format as /search operation.
28 29 30 31 |
# File 'lib/manticore/client/api/utils_api.rb', line 28 def sql(body, opts = {}) data, _status_code, _headers = sql_with_http_info(body, opts) data end |
#sql_with_http_info(body, opts = {}) ⇒ Array<(SqlResponse, Integer, Hash)>
Perform SQL requests Run a query in SQL format. Expects a query string passed through `body` parameter and optional `raw_response` parameter that defines a format of response. `raw_response` can be set to `False` for Select queries only, e.g., `SELECT * FROM mytable` The query string must stay as it is, no URL encoding is needed. The response object depends on the query executed. In select mode the response has same format as `/search` operation.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/manticore/client/api/utils_api.rb', line 39 def sql_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UtilsApi.sql ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling UtilsApi.sql" end # resource path local_var_path = '/sql' # query parameters query_params = opts[:query_params] || {} query_params[:'raw_response'] = opts[:'raw_response'] if !opts[:'raw_response'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['text/plain']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'SqlResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"UtilsApi.sql", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UtilsApi#sql\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |